"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PiAPITaskStatus = void 0;
const GenericFunctions_1 = require("../shared/GenericFunctions");
class PiAPITaskStatus {
    constructor() {
        this.description = {
            displayName: 'PiAPI Task Status',
            name: 'piAPITaskStatus',
            icon: 'file:../piapi.svg',
            group: ['transform'],
            version: 1,
            description: 'Check the status of a PiAPI task',
            defaults: {
                name: 'PiAPI Task Status',
            },
            inputs: ["main"],
            outputs: ["main"],
            credentials: [
                {
                    name: 'piAPIApi',
                    required: true,
                },
            ],
            properties: [
                {
                    displayName: 'Task ID',
                    name: 'taskId',
                    type: 'string',
                    default: '',
                    required: true,
                    description: 'The ID of the task to check',
                },
                {
                    displayName: 'Return Only Media URL',
                    name: 'returnOnlyImageUrl',
                    type: 'boolean',
                    default: false,
                    description: 'Whether to return only the image/video URL instead of the full task data',
                },
                {
                    displayName: 'Return Binary Data',
                    name: 'returnBinaryData',
                    type: 'boolean',
                    default: false,
                    description: 'Whether to return the Image/Video as binary data',
                },
                {
                    displayName: 'Binary Property',
                    name: 'binaryPropertyName',
                    type: 'string',
                    default: 'data',
                    required: true,
                    displayOptions: {
                        show: {
                            returnBinaryData: [true],
                        },
                    },
                    description: 'Name of the binary property to which to write the data of the image',
                },
            ],
        };
    }
    async execute() {
        var _a, _b, _c, _d, _e, _f;
        const items = this.getInputData();
        const returnData = [];
        for (let i = 0; i < items.length; i++) {
            const taskId = this.getNodeParameter('taskId', i);
            const returnOnlyImageUrl = this.getNodeParameter('returnOnlyImageUrl', i, false);
            const returnBinaryData = this.getNodeParameter('returnBinaryData', i, false);
            const binaryPropertyName = returnBinaryData
                ? this.getNodeParameter('binaryPropertyName', i)
                : '';
            try {
                const response = await GenericFunctions_1.piApiRequest.call(this, 'GET', `/api/v1/task/${taskId}`);
                const mediaUrl = ((_b = (_a = response.data) === null || _a === void 0 ? void 0 : _a.output) === null || _b === void 0 ? void 0 : _b.image_url) || ((_d = (_c = response.data) === null || _c === void 0 ? void 0 : _c.output) === null || _d === void 0 ? void 0 : _d.video_url);
                if (returnOnlyImageUrl && mediaUrl) {
                    returnData.push({
                        json: {
                            mediaUrl,
                            type: ((_f = (_e = response.data) === null || _e === void 0 ? void 0 : _e.output) === null || _f === void 0 ? void 0 : _f.image_url) ? 'image' : 'video',
                        },
                    });
                }
                else if (returnBinaryData && mediaUrl) {
                    const imageUrl = mediaUrl;
                    const imageData = await this.helpers.request({
                        method: 'GET',
                        url: imageUrl,
                        encoding: null,
                        resolveWithFullResponse: true,
                    });
                    const newItem = {
                        json: response.data,
                        binary: {},
                    };
                    if (newItem.binary) {
                        newItem.binary[binaryPropertyName] = await this.helpers.prepareBinaryData(Buffer.from(imageData.body), imageUrl.split('/').pop() || 'image.png', imageData.headers['content-type']);
                    }
                    returnData.push(newItem);
                }
                else {
                    returnData.push({
                        json: response.data,
                    });
                }
            }
            catch (error) {
                if (this.continueOnFail()) {
                    returnData.push({
                        json: {
                            error: error.message,
                        },
                    });
                    continue;
                }
                throw error;
            }
        }
        return [returnData];
    }
}
exports.PiAPITaskStatus = PiAPITaskStatus;
//# sourceMappingURL=PiAPITaskStatus.node.js.map