"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.piApiRequest = piApiRequest;
exports.waitForTaskCompletion = waitForTaskCompletion;
const n8n_workflow_1 = require("n8n-workflow");
async function piApiRequest(method, resource, body = {}, qs = {}) {
    const credentials = await this.getCredentials('piAPIApi');
    const options = {
        method,
        body,
        qs,
        url: `https://api.piapi.ai${resource}`,
        headers: {
            'Content-Type': 'application/json',
            'X-API-Key': credentials.apiKey,
        },
        json: true,
    };
    try {
        return await this.helpers.request(options);
    }
    catch (error) {
        throw new n8n_workflow_1.NodeApiError(this.getNode(), error);
    }
}
async function waitForTaskCompletion(taskId, maxRetries = 20, retryInterval = 3000) {
    var _a, _b;
    let retries = 0;
    while (retries < maxRetries) {
        const response = await piApiRequest.call(this, 'GET', `/api/v1/task/${taskId}`);
        const status = (_a = response.data) === null || _a === void 0 ? void 0 : _a.status;
        if (status === 'success' || status === 'completed') {
            return response.data;
        }
        if (status === 'failed') {
            throw new Error(`Task failed: ${JSON.stringify(((_b = response.data) === null || _b === void 0 ? void 0 : _b.error) || 'Unknown error')}`);
        }
        await new Promise(resolve => setTimeout(resolve, retryInterval));
        retries++;
    }
    throw new Error(`Task timed out after ${maxRetries} retries`);
}
//# sourceMappingURL=GenericFunctions.js.map